|buildstatus|_
|coverage|_

Irwin
=====

Project homepage: https://github.com/eerimoq/irwin

Installation
------------

.. code-block:: python

   $ pip install irwin

.. |buildstatus| image:: https://travis-ci.com/eerimoq/irwin.svg?branch=master
.. _buildstatus: https://travis-ci.com/eerimoq/irwin

.. |coverage| image:: https://coveralls.io/repos/github/eerimoq/irwin/badge.svg?branch=master
.. _coverage: https://coveralls.io/github/eerimoq/irwin
